Chapter 1. Setting up the XML Résumé Library

# XMLRésuméLibrary: User Guide

Part I. Getting Started | Part I. Getting Started | Getting the Software

# Setting up the XML Résumé Library

### Peter Hutnick

#### Edited by

### Bruce Christensen

### Mark Miller

Copyright © 2002 Peter Hutnick

This chapter explains how to install the XML Résumé Library, an Open Source, XML based résumé management system, on UNIX systems. It is written based on the author's experience installing on a Red Hat Linux system. Other systems may vary somewhat.

## Prerequisites

### Java

The resources in this document provide enough information to convert your XML résumé to HTML, PDF, and plain text. The programs to exploit these resources, however, are not included. Any capable XML parser, XSLT stylesheet processor and XSL formatting objects processor will get the job done. Many of the XML Résumé Library developers use the free tools produced by the Apache XML Project, and we recommend that you do as well. These tools include Xerces, Xalan, and FOP.

For the purposes of this document a functioning JRE (Java Runtime Environment) is a requirement. Obtaining and installing a JRE is outside the scope of this document. However, you might find Sun's J2SE web site a good starting point.

### XML

A minimal understanding of XML is an asset for using the XML Résumé Library. Most users find that they can get by following the examples in the absence of XML experience.

For a more in-depth tutorial on authoring a résumé in XML, see the section called “Writing your first XML Résumé”. For a reference on XML elements available in the XML Résumé Library DTD, see Element Reference.

Part I. Getting Started | Part I. Getting Started | Getting the Software